Merge http://members.cox.net/junkio/git-jc.git/
authorLinus Torvalds <torvalds@ppc970.osdl.org>
Thu, 5 May 2005 01:18:40 +0000 (18:18 -0700)
committerLinus Torvalds <torvalds@ppc970.osdl.org>
Thu, 5 May 2005 01:18:40 +0000 (18:18 -0700)
blob.c
commit.c
fsck-cache.c
git-prune-script [changed mode: 0755->0644]
git-pull-script
object.c
tag.c
tree.c

diff --git a/blob.c b/blob.c
index d4af4a3..625db43 100644 (file)
--- a/blob.c
+++ b/blob.c
@@ -34,6 +34,7 @@ int parse_blob(struct blob *item)
         if (!buffer)
                 return error("Could not read %s",
                              sha1_to_hex(item->object.sha1));
+       free(buffer);
         if (strcmp(type, blob_type))
                 return error("Object %s not a blob",
                              sha1_to_hex(item->object.sha1));
index 3956c7b..b45118a 100644 (file)
--- a/object.c
+++ b/object.c
@@ -107,11 +107,12 @@ struct object *parse_object(unsigned char *sha1)
                char type[100];
                unsigned long size;
                void *buffer = unpack_sha1_file(map, mapsize, type, &size);
+               munmap(map, mapsize);
                if (!buffer)
                        return NULL;
                if (check_sha1_signature(sha1, buffer, size, type) < 0)
                        printf("sha1 mismatch %s\n", sha1_to_hex(sha1));
-               munmap(map, mapsize);
+               free(buffer);
                if (!strcmp(type, "blob")) {
                        struct blob *ret = lookup_blob(sha1);
                        parse_blob(ret);
diff --git a/tag.c b/tag.c
index 406dba2..3a71dd4 100644 (file)
--- a/tag.c
+++ b/tag.c
@@ -37,37 +37,46 @@ int parse_tag(struct tag *item)
         if (!data)
                 return error("Could not read %s",
                              sha1_to_hex(item->object.sha1));
-        if (strcmp(type, tag_type))
+        if (strcmp(type, tag_type)) {
+               free(data);
                 return error("Object %s not a tag",
                              sha1_to_hex(item->object.sha1));
+       }
 
        if (size < 64)
-               return -1;
+               goto err;
        if (memcmp("object ", data, 7) || get_sha1_hex(data + 7, object))
-               return -1;
+               goto err;
 
        item->tagged = parse_object(object);
+       if (item->tagged)
+               add_ref(&item->object, item->tagged);
 
        type_line = data + 48;
        if (memcmp("\ntype ", type_line-1, 6))
-               return -1;
+               goto err;
 
        tag_line = strchr(type_line, '\n');
        if (!tag_line || memcmp("tag ", ++tag_line, 4))
-               return -1;
+               goto err;
 
        sig_line = strchr(tag_line, '\n');
        if (!sig_line)
-               return -1;
+               goto err;
        sig_line++;
 
        typelen = tag_line - type_line - strlen("type \n");
        if (typelen >= 20)
-               return -1;
+               goto err;
        taglen = sig_line - tag_line - strlen("tag \n");
        item->tag = xmalloc(taglen + 1);
        memcpy(item->tag, tag_line + 4, taglen);
        item->tag[taglen] = '\0';
 
+       free(data);
        return 0;
+
+err:
+       free(data);
+       return -1;
 }
diff --git a/tree.c b/tree.c
index 72305a3..4a26603 100644 (file)
--- a/tree.c
+++ b/tree.c
@@ -101,9 +101,11 @@ int parse_tree(struct tree *item)
        if (!buffer)
                return error("Could not read %s",
                             sha1_to_hex(item->object.sha1));
-       if (strcmp(type, tree_type))
+       if (strcmp(type, tree_type)) {
+               free(buffer);
                return error("Object %s not a tree",
                             sha1_to_hex(item->object.sha1));
+       }
        list_p = &item->entries;
        while (size) {
                struct object *obj;
@@ -113,8 +115,10 @@ int parse_tree(struct tree *item)
                char *path = strchr(bufptr, ' ');
                unsigned int mode;
                if (size < len + 20 || !path || 
-                   sscanf(bufptr, "%o", &mode) != 1)
+                   sscanf(bufptr, "%o", &mode) != 1) {
+                       free(buffer);
                        return -1;
+               }
 
                entry = xmalloc(sizeof(struct tree_entry_list));
                entry->name = strdup(path + 1);
@@ -138,5 +142,6 @@ int parse_tree(struct tree *item)
                *list_p = entry;
                list_p = &entry->next;
        }
+       free(buffer);
        return 0;
 }
--- a/commit.c
+++ b/commit.c
@@ -54,9 +54,11 @@ int parse_commit(struct commit *item)
        if (!buffer)
                return error("Could not read %s",
                             sha1_to_hex(item->object.sha1));
-       if (strcmp(type, commit_type))
+       if (strcmp(type, commit_type)) {
+               free(buffer);
                return error("Object %s not a commit",
                             sha1_to_hex(item->object.sha1));
+       }
        get_sha1_hex(bufptr + 5, parent);
        item->tree = lookup_tree(parent);
        if (item->tree)
index 5db07e0..301cc67 100644 (file)
@@ -300,14 +300,12 @@ int main(int argc, char **argv)
                        continue;
 
                if (!get_sha1(arg, head_sha1)) {
-                       struct commit *commit = lookup_commit(head_sha1);
-                       struct object *obj;
+                       struct object *obj = lookup_object(head_sha1);
 
-                       /* Error is printed by lookup_commit(). */
-                       if (!commit)
+                       /* Error is printed by lookup_object(). */
+                       if (!obj)
                                continue;
 
-                       obj = &commit->object;
                        obj->used = 1;
                        mark_reachable(obj, REACHABLE);
                        heads++;
old mode 100755 (executable)
new mode 100644 (file)
index 30a989e..9ba89a5
@@ -1,5 +1,4 @@
 #!/bin/sh
-
 dryrun=
 while case "$#" in 0) break ;; esac
 do
index 4220e18..e7e82f4 100755 (executable)
@@ -4,6 +4,7 @@
 # just hard-codes it.
 #
 merge_repo=$1
+merge_name=${2:-HEAD}
 
 rm -f .git/MERGE_HEAD .git/ORIG_HEAD
 cp .git/HEAD .git/ORIG_HEAD
@@ -11,8 +12,8 @@ cp .git/HEAD .git/ORIG_HEAD
 echo "Getting object database"
 rsync -avz --ignore-existing $merge_repo/objects/. ${SHA1_FILE_DIRECTORY:-.git/objects}/.
 
-echo "Getting remote head"
-rsync -L $merge_repo/HEAD .git/MERGE_HEAD || exit 1
+echo "Getting remote $merge_name"
+rsync -L $merge_repo/$merge_name .git/MERGE_HEAD || exit 1
 
 head=$(cat .git/HEAD)
 merge_head=$(cat .git/MERGE_HEAD)
@@ -54,3 +55,4 @@ result_commit=$(echo "$merge_msg" | git-commit-tree $result_tree -p $head -p $me
 echo "Committed merge $result_commit"
 echo $result_commit > .git/HEAD
 git-checkout-cache -f -a && git-update-cache --refresh
+git-diff-tree -p ORIG_HEAD HEAD | diffstat -p1
index ca4af8f..c1f2291 100644 (file)